## Features

Some of it’s stand out features are:

## Installation

Installing with:

```bash
pip install 'django-insights'
```

## Usage

Write more about using code in other projects

## Documentation

Write more about where to find documentation

## Ideas

-

## Is it any good?

[Yes.](http://news.ycombinator.com/item?id=3067434)

## License

The MIT License
